<?php

namespace App\Http\Controllers;

use App\Http\Requests\FirmApplicationsRequest;
use App\Http\Requests\FirmGetRequirementRequest;
use App\Http\Requests\PostRequirementRequest;
use App\Models\FirmRequirement;
use App\Models\User;
use App\Models\UserApplication;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class FirmDetailsController extends Controller
{
    public function postRequirements(PostRequirementRequest $request){
        try {
            if($request->input('looking_role_id')){
                $userDetails = new FirmRequirement();
                $userDetails->user_id = Auth::user()->id;
                $userDetails->looking_role_id = $request->input('looking_role_id');
                $userDetails->maximum_no_of_ipcc_attempts = $request->input('maximum_no_of_ipcc_attempts');
                $userDetails->qualification_needed = $request->input('qualification_needed');
                $userDetails->minimum_test_mark = $request->input('minimum_test_mark');
                $userDetails->other_requirements = $request->input('other_requirements');
                $userDetails->prefered_gender = $request->input('prefered_gender');
                $userDetails->work_experience = $request->input('work_experience');
                $userDetails->area = $request->input('area');
                $data=$userDetails->save();

                return response()->json([
                    'message' => 'Successfully posted',
                    'status'=>true
                ], 200);
            }


        }catch (\Exception $exception){
            return response()->json(['message'=>$exception->getMessage()],500);
        }

    }
    public function getAllRequirements(FirmGetRequirementRequest $request){
        try {

            $limit=$request->limit;
            $start=$request->start;



            $sort_by=$request->sort_by;
            $filter=$request->filter;

            $user_id =Auth::user()->id;

            if($sort_by!=NULL){
                if($sort_by == "application_status")
                    $sort_by1='user_applications.application_status';
                if($sort_by == "firm_zone")
                    $sort_by1='users.location_zone';

            }else{
                $sort_by1='firm_requirements.id';
            }



            $result = FirmRequirement::leftjoin('users','users.id','firm_requirements.user_id')
            ->leftjoin('location_zones','users.location_zone','location_zones.id')
            ->leftjoin('qualifications','qualifications.id','firm_requirements.qualification_needed')
            ->leftjoin('firm_details','firm_details.user_id','users.id')
            // ->leftjoin('user_applications','user_applications.firm_requirement_id','firm_requirements.id')
            ->where(function($query) use ($filter) {
                if($filter!=NULL){
                for($i=0;$i<count($filter);$i++){

                    if($filter[$i]['filter_by'] == 'ipcc_attempts'){
                        $query->where('firm_requirements.maximum_no_of_ipcc_attempts', 'like', '%'.$filter[$i]['filter_value'].'%');
                     }
                     elseif($filter[$i]['filter_by'] == 'looking_role_id'){

                        $query->orWhere('firm_requirements.looking_role_id', 'like', '%'.$filter[$i]['filter_value'].'%');
                     }
                     elseif($filter[$i]['filter_by'] == 'prefered_gender'){
                        $query->orWhere('firm_requirements.prefered_gender', 'like', '%'.$filter[$i]['filter_value'].'%');
                    }

                    elseif($filter[$i]['filter_by'] == 'qualification'){
                        $query->orWhere('firm_requirements.qualification_needed', 'like', '%'.$filter[$i]['filter_value'].'%');
                    }
                    elseif($filter[$i]['filter_by'] == 'requirement_status'){
                        $query->orWhere('firm_requirements.approval_status', 'like', '%'.$filter[$i]['filter_value'].'%');
                    }

                }
              }
            })
           ->where('firm_requirements.user_id',Auth::user()->id)

            ->select('firm_requirements.id','users.id as firm_id','users.name as firm_name','users.location_zone','firm_requirements.looking_role_id',
            DB::raw("CASE WHEN firm_requirements.looking_role_id='2' THEN 'Student' ELSE 'Employee' END as looking_role")
            ,DB::raw("CASE WHEN firm_requirements.prefered_gender='0' THEN 'Male' WHEN firm_requirements.prefered_gender='2' THEN 'Others' ELSE 'Female' END as gender"),
            'firm_requirements.maximum_no_of_ipcc_attempts','firm_requirements.area',
            'firm_requirements.work_experience',
            'firm_requirements.minimum_test_mark',
            'firm_requirements.other_requirements',
            //'user_applications.application_status',
            //'location_zones.location as firm_location_zone',
            'qualifications.name as qualification_needed','firm_requirements.prefered_gender',
            'firm_requirements.approval_status as requirement_status'
            ,DB::raw('DATE_FORMAT(firm_requirements.created_at, "%d-%b-%Y") as posted_date'))
            ->withCount(['getAllApplications'=> function ($query) {
                $query->where('user_applications.application_status',"<>","applied");
            }])
            ->orderBy(DB::raw($sort_by1),'ASC');


            $count= $result->count();
            $results=$result->skip($start)->limit($limit)->get();

            if($user_id){
                $res1= $result->where('firm_requirements.user_id',$user_id);
            }
            return    response()->json(['message'=>'Requirement List','list' => $results,'count'=>$count,'status'=>true],200);

        }catch (\Exception $exception){
            return response()->json(['message'=>$exception->getMessage()],500);
        }
    }
    public function getAllApplications(FirmApplicationsRequest $request){
        try {

            $limit=$request->limit;
            $start=$request->start;
            // $userid=$request->userid;
            // $status=$request->status;


            $id = $request->id;
            // $firm_id = $request->firm_id;
            $firm_id = Auth::user()->id;
            $sort=$request->sort;
            $filter=$request->filter;
            //$filter_value=$request->filter_value;'

            $firm = User::where('id',$firm_id)->select('id as firm_id','name as firm_name')->get();

            if(!empty($sort)){
                if($sort[0]['sort_by'] == "created_at" && $sort[0]['sort_order'] == "ASC")
                    $sort_by1='user_applications.created_at';
                    $sort_order1=$sort[0]['sort_order'];
                if($sort[0]['sort_by'] == "created_at" && $sort[0]['sort_order'] == "DESC")
                    $sort_by1='user_applications.created_at';
                    $sort_order1=$sort[0]['sort_order'];
                if($sort[0]['sort_by'] == "score" && $sort[0]['sort_order'] == "ASC")
                    $sort_by1='user_exam_details.total_score';
                    $sort_order1=$sort[0]['sort_order'];
                if($sort[0]['sort_by'] == "score" && $sort[0]['sort_order'] == "DESC")
                    $sort_by1='user_exam_details.total_score';
                    $sort_order1=$sort[0]['sort_order'];
            }else{
                $sort_by1='user_applications.id';
                $sort_order1="DESC";
            }


            $result = UserApplication::leftjoin('users','users.id','user_applications.user_id')
            ->leftjoin('location_zones','users.location_zone','location_zones.id')
            ->leftjoin('user_details','user_details.user_id','user_applications.user_id')
            ->leftjoin('user_exam_details','user_exam_details.user_id','user_applications.user_id')
            ->leftjoin('qualifications','qualifications.id','user_details.qualification_id')
            ->where(function($query) use ($filter) {
                if($filter!=NULL){
                    for($i=0;$i<count($filter);$i++){
                        if($filter[$i]['filter_by'] == 'ipcc_attempts'){
                            $query->where('user_details.ipcc_number_of_attempts', 'like', '%'.$filter[$i]['filter_value'].'%');
                        }
                        if($filter[$i]['filter_by'] == 'application_status'){
                            $query->orWhere('user_applications.application_status', 'like', '%'.$filter[$i]['filter_value'].'%');
                        }
                        if($filter[$i]['filter_by'] == 'gender'){
                            $query->orWhere('users.gender', 'like', '%'.$filter[$i]['filter_value'].'%');
                        }
                        if($filter[$i]['filter_by'] == 'qualification'){
                            $query->orWhere('user_details.qualification_id', 'like', '%'.$filter[$i]['filter_value'].'%');
                        }
                    }
                }
            })
            ->with(['getWorkExperience'=> function ($query) {
                $query->select('id','no_of_years');
            }])
            ->where('user_applications.application_status','<>','applied')
            // ->where(function($query) use ($userid,$status) {
            //     if($userid!=''){
            //         if($status=='')
            //         {
            //             $query->where('user_applications.user_id',$userid);
            //         }
            //         else
            //         {
            //             $query->where(['user_applications.user_id'=>$userid,
            //                 'user_applications.application_status'=>$status
            //              ]);
            //         }
            //     }
            // })
            ->where('user_applications.firm_requirement_id',$id)
            ->select('user_applications.id','users.id as user_id','users.name as user_applied','user_exam_details.total_score as user_mark',
            DB::raw("CASE WHEN users.role_id='2' THEN 'Student' ELSE 'Employee' END as type")
            ,'users.gender',DB::raw("CASE WHEN users.gender='0' THEN 'Male' WHEN users.gender='2' THEN 'Others' ELSE 'Female' END as user_gender"),
            'user_details.ipcc_number_of_attempts',
            'user_details.career_objectives',
            'qualifications.id as qualification_id',
            'qualifications.name as qualification','users.gender',
            'location_zones.location as user_location_zone',
            'user_applications.application_status as application_status'
            ,DB::raw('DATE_FORMAT(user_applications.created_at, "%d-%b-%Y") as applied_date'))
            ->orderBy($sort_by1,$sort_order1);


            $count= $result->count();
            $results=$result->skip($start)->limit($limit)->get();

            return    response()->json(['message'=>'Firm Application List','list' => $results,'count'=>$count,'firm_name'=>$firm,'status'=>true],200);
        }
        catch (\Exception $exception){
        }

    }
    public function getApplicantProfile(FirmApplicationsRequest $request){
           
        try {

            $aid = $request->aid;
            $firm_id = Auth::user()->id;

            $result = User::leftjoin('user_exam_details','user_exam_details.user_id','users.id')
            ->leftjoin('user_applications','user_applications.user_id','users.id')
            ->leftjoin('user_details','user_details.user_id','users.id')
            ->leftJoin('roles', 'roles.id','users.role_id')
            ->leftjoin('location_zones as l','users.location_zone','l.id')
            ->leftjoin('location_zones as p','users.prefered_location_to_work','p.id')
            ->leftjoin('qualifications','qualifications.id','user_details.qualification_id')
                // ->leftjoin('courses','courses.id','user_details.course_id')

            ->with(['getAllWorkExperiences'])
            ->with(['getAllCoursesPursuing.getCourseName'=> function ($query) {
                //$join->on('courses','courses.id','user_course_pursuings.course_id');
                $query->select('courses.id','courses.name as course_name');

            }])
            // ->with(['getAllShortlisted'=> function ($query) {
            //     $query->where('user_applications.application_status', 1);
            // }])
            ->where('user_applications.id',$aid)
            ->select('users.id','roles.name as role','users.name',DB::raw('DATE_FORMAT(users.dob, "%d-%b-%Y") as dob'),'users.email','users.sro_number','users.location_zone','l.location','users.prefered_location_to_work','p.location as plocation',
            DB::raw("CASE WHEN users.gender='0' THEN 'Male' WHEN users.gender='1' THEN 'Female' ELSE 'Others' END as gender"),'user_exam_details.total_score',
            DB::raw("CASE WHEN user_details.selection_status='0' THEN 'Not appointed' ELSE 'appointed' END as appointed_status"),
            'users.address','user_details.college_name','user_details.tenth_passed_year','user_details.tenth_percentage','user_details.twelfth_passed_year',
            'user_details.twelfth_percentage','user_details.cpt_number_of_attempts','user_details.ipcc_number_of_attempts','user_details.degree','user_details.other_professional_course',
            'user_details.achievements','user_details.career_objectives','user_details.extra_curicular_activities','user_details.skills',
            'user_details.other_professional_achievements','user_details.resume','user_details.employment_type',
            'user_details.cpt_percentage','user_details.cpt_passed_year',
            'user_details.ipcc_percentage','user_details.ipcc_passed_year',
            DB::raw("CASE WHEN user_details.itt_orientation_status='0' THEN 'incompleted' ELSE 'completed' END as itt_orientation_status")
            ,'user_details.qualification_id','qualifications.name as qualification'
            ,'users.mobile',DB::raw("CASE WHEN users.profile_status='0' THEN 'Registered' WHEN users.profile_status='1' THEN 'Completed' WHEN users.profile_status='2' THEN 'Attended Exam' END as profile_status")
            ,'user_exam_details.total_score',
            'user_applications.application_status as application_status',
            'user_applications.offer_letter',
            DB::raw('DATE_FORMAT(users.created_at, "%d-%b-%Y") as joined_date'),
            DB::raw('DATE_FORMAT(user_applications.created_at, "%d-%b-%Y") as applied_date'))
            // ->withCount('getAllApplications')
            // ->withCount(['getAllShortlisted'=> function ($query) {
            //     $query->where('user_applications.application_status', 1);
            // }])
            ->get();
            return    response()->json(['message'=>'Details of a Student/Employee','details' => $result,'status'=>true],200);

        }catch (\Exception $exception){
            return response()->json(['message'=>$exception->getMessage()],500);
        }

    }
    public function updateApplicationStatus(FirmApplicationsRequest $request){
        try{

            $aid = $request->input('aid');
            $status = $request->input('status');
            $application = UserApplication::where('id', $aid)->first();

            if ($application) {

                $application->application_status = $status;
                $application->save();

                return    response()->json(['message'=>'Status updated successfully','application_status'=>$status,'status'=>true],200);

            }else {
                return    response()->json(['message'=>'No such application exists with id : '.$aid,'status'=>false],200);

            }
        }catch (\Exception $exception){
            return response()->json(['message'=>$exception->getMessage()],500);
        }

    }
    public function offerApplicant(FirmApplicationsRequest $request){
        try{

            $aid = $request->input('aid');            
            $application = UserApplication::where('id', $aid)->first();
            $files = $request->file('offer_letter');
            if ($application) {

                if(!$files){
                    return  response()->json(['message'=>'No such file uploaded','status'=>false],200);
                }
                //store file into offers folder

                $filename = $files->getClientOriginalName();
                $extension = $files->getClientOriginalExtension();
                $picture = date('His').$filename;
                $path ='/offers';
                $destinationPath = public_path().'/offers';
                $file = $request->file('offer_letter') ? $files->move($destinationPath, $picture) : null;

                $application->offer_letter = $path.'/'.$picture;
                $application->application_status = 'offered';
                $application->save();

                return    response()->json([
                    'message'=>'Status updated successfully',
                    'application_status'=>'offered',
                    'offer_letter'=>$path.'/'.$picture,
                    'status'=>true],200);
               
            }else {
                return    response()->json(['message'=>'No such application exists with id : '.$aid,'status'=>false],200);
            }

        }catch (\Exception $exception){
            return response()->json(['message'=>$exception->getMessage()],500);
        }        

    }
}
